a_star_search

Function a_star_search 

pub fn a_star_search<T>(start: T, end: T, map: &dyn BaseMap) -> NavigationPath
where T: TryInto<usize>,
Request an A-Star search. The start and end are specified as index numbers (compatible with your BaseMap implementation), and it requires access to your map so as to call distance and exit determinations.