field_of_view_set

Function field_of_view_set 

pub fn field_of_view_set(
    center: Point,
    range: i32,
    fov_check: &dyn Algorithm2D,
) -> HashSet<Point>
Calculates field-of-view for a map that supports Algorithm2D, returning a HashSet. This is a bit faster than coercing the results into a vector, since internally it uses the set for de-duplication.